import * as React$1 from 'react';
import React__default from 'react';

declare enum Breakpoints {
    SMALL = 0,
    MEDIUM = 1,
    LARGE = 2,
    XLARGE = 3
}

interface BreakpointsObject {
    s?: number;
    m?: number;
    l?: number;
}

type IDialogController = {
    openDialog: (dialogId: string) => void;
    closeDialog: (dialogId: string) => void;
    openedDialogs: string[];
};

declare enum ColorCategories {
    fonts = "fonts",
    primary = "primary",
    secondary = "secondary",
    tertiary = "tertiary",
    positive = "positive",
    negative = "negative",
    error = "error",
    warning = "warning"
}
/**
 * The intention of this type is that we can use it to set props from components that can have
 * different colorations. E.G.
 *
 * <UiBadge theme="primary" /> where `theme` prop could be typed as ColorCategory.
 */
type ColorCategory = 'primary' | 'secondary' | 'tertiary' | 'positive' | 'negative' | 'error' | 'warning' | 'fonts';

declare enum ColorTokens {
    token_10 = "token_10",
    token_50 = "token_50",
    token_100 = "token_100",
    token_150 = "token_150",
    token_200 = "token_200"
}
/**
 * The intention of this type is that we can use it to set props from components that can have
 * different weight colorations. E.G.
 *
 * <UiText weight="50" /> where `weight` correspond to a different level of token
 */
type ColorToken = '10' | '50' | '100' | '150' | '200';

declare enum HeadingLevel {
    level1 = "level1",
    level2 = "level2",
    level3 = "level3",
    level4 = "level4",
    level5 = "level5",
    level6 = "level6"
}

declare enum Sizing {
    one = "one",
    two = "two",
    three = "three",
    four = "four",
    five = "five",
    six = "six",
    seven = "seven"
}
type SpacingType = 'one' | 'two' | 'three' | 'four' | 'five' | 'six' | 'seven';

declare enum ThemeColor {
    light = "light",
    dark = "dark"
}

declare enum TextSize {
    xsmall = "xsmall",
    small = "small",
    regular = "regular",
    large = "large",
    xlarge = "xlarge"
}
type SizesProp = 'xsmall' | 'small' | 'regular' | 'large' | 'xlarge';

type Coloration = {
    [key in ColorCategories]: Tokens;
};

type HeadingSizes = {
    [key in HeadingLevel]: string;
};
type TextSizes = {
    [key in TextSize]: string;
};
type Sizes = {
    headings: HeadingSizes;
    texts: TextSizes;
};

type Texts = {
    /** Set of fonts to be used in the application */
    font: string;
};

type Spacing = {
    [key in Sizing]: string;
};

type Tokens = {
    [key in ColorTokens]: string;
};

type Theme = {
    /** Identifier of the theme */
    name: string;
    /** Texts values */
    texts: Texts;
    /** Set of sizes for theme */
    sizes: Sizes;
    /** Set of color tokens for the light theme */
    light: Coloration;
    /** Set of color tokens for the dark theme */
    dark: Coloration;
    /** Set of tokens spacing */
    spacing: Spacing;
};
declare enum ThemeProperties {
    name = "name",
    texts = "texts",
    sizes = "sizes",
    light = "light",
    dark = "dark",
    spacing = "spacing"
}

/** Enum of possible HTML states */
declare enum ThemeMapperStates {
    normal = "normal",
    hover = "hover",
    active = "active",
    selected = "selected",
    disabled = "disabled",
    visited = "visited",
    focus = "focus"
}
/** Enum of possible CSS properties */
declare enum ThemeMapperStyles {
    color = "color",
    background = "background",
    borderColor = "border-color",
    fill = "fill"
}
type ThemeMapperValue = {
    /** Color category to be used in the current property */
    category: ColorCategories;
    /** Color token to be used in the current style */
    token: ColorTokens;
    /** Inverse theme, if dark is selected, light color will be used */
    inverse: boolean;
};
type ThemeMapperStyle = {
    [key in ThemeMapperStyles]?: ThemeMapperValue;
};
type ThemeMapper = {
    [key in ThemeMapperStates]?: ThemeMapperStyle;
};

interface UiReactElementProps {
    /** Children components to render inside a react element */
    children?: React.ReactNode;
    /** Class name for HTML element */
    className?: string;
    /** Test id attribute used for UI Automation testing */
    testId?: string;
}
type UiReactPrivateElementProps = UiReactElementProps & {
    /** Theme that is being used to retrieve tokens */
    $customTheme: Theme;
    /** selected theme color */
    $selectedTheme: ThemeColor;
};

type SpacingDistribution = {
    /** Applies size to all sides */
    all?: SpacingType;
    /** Applies size to top and bottom */
    block?: SpacingType;
    /** Applies size to left and right */
    inline?: SpacingType;
    /** Applies size to left */
    left?: SpacingType;
    /** Applies size to right */
    right?: SpacingType;
    /** Applies size to top */
    top?: SpacingType;
    /** Applies size to bottom */
    bottom?: SpacingType;
};

type UiNotificationLink = {
    /** The notification link label */
    label: string;
    /** The notification link url */
    url: string;
    /** The notification link target */
    target?: string;
};
type UiNotification = {
    /** The notification icon */
    icon?: string;
    /** The notification title */
    title?: string;
    /** The notification message */
    message?: string;
    /** The notification link */
    link?: UiNotificationLink;
    /** The notification options */
    options?: UiNotificationOptions;
};
type UiNotificationOptions = {
    /** The color catefory of the notificaion */
    category?: ColorCategory;
    /** The timer for the notification to be removed, if 0 provide then it won't be removed automatically. */
    timer?: number;
    /** If the close button should render */
    closeButton?: boolean;
    /** Triggers callback when link is clicked */
    onLinkClicked?: (event: React.MouseEvent<HTMLAnchorElement>) => void;
    /** Triggers callback when notification is shown */
    onNotificationShown?: () => void;
    /** Triggers callback when notification is dismissed */
    onNotificationDismissed?: () => void;
};

type INotificationsController = {
    showNotification: (notification: UiNotification) => void;
    notifications: UiNotification[];
};

type UiConfirmDialogData = {
    title: string;
    message: string;
    confirmLabel: string;
    denyLabel: string;
};
type UiConfirmDialogOptions = {
    direction?: 'inline' | 'stacked';
};
type UiConfirmDialogHolder = {
    data: UiConfirmDialogData;
    confirm: () => void;
    deny: () => void;
    options?: UiConfirmDialogOptions;
};

type IConfirmDialogController = {
    visible: boolean;
    confirmDialog: UiConfirmDialogHolder | null;
    showConfirmDialog: (notification: UiConfirmDialogData, onConfirm: () => void, onDeny: () => void, options?: UiConfirmDialogOptions) => void;
    hideConfirmDialog: () => void;
};

declare const useDialogController: () => IDialogController;

type useViewportResponse = {
    isSmall: boolean;
    isMedium: boolean;
    isLarge: boolean;
    isXLarge: boolean;
};
declare const useViewport: () => useViewportResponse;

declare const useNotificationsController: () => INotificationsController;

declare const useConfirmDialogController: () => IConfirmDialogController;

declare const UiDialogsControllerContext: React__default.Context<IDialogController>;

declare const ThemeContext: React__default.Context<{
    selectedTheme: ThemeColor;
}>;

declare const UiNotificationsContext: React__default.Context<INotificationsController>;

declare const UiConfirmDialogContext: React__default.Context<IConfirmDialogController>;

type BreakpointString = 's|m' | 'm|l' | 'l|xl' | 'm|l|xl';
interface ViewportProps {
    children?: React$1.ReactNode;
    /** Breakpoint(s) criteria where UiViewport render it children see [Breakpoints Enum](./packages-foundation-docs-breakpoints) */
    criteria: Breakpoints | BreakpointString;
    skipSSr?: boolean;
}
declare const UiViewport: React$1.FC<ViewportProps>;

type UiSpacingProps = UiReactElementProps & {
    /** Margin to use based on [SpacingDistribution](./packages-foundation-docs-spacing#spacingDistribution) */
    margin?: SpacingDistribution;
    /** Padding to use based on [SpacingDistribution](./packages-foundation-docs-spacing#spacingDistribution) */
    padding?: SpacingDistribution;
    /** For rendering the spacing as inline block */
    inline?: boolean;
};
declare const UiSpacing: React$1.FC<UiSpacingProps>;
/**
 *
 * @deprecated("Stop Using this, will be removed on v3")
 * @param sizing
 * @returns string
 */
declare const getSpacingStyle: (sizing: SpacingDistribution) => string;

declare const getSpacingClass: (type: 'margin' | 'padding', spacing?: SpacingDistribution) => string;

export { Breakpoints, type BreakpointsObject, ColorCategories, type ColorCategory, type ColorToken, ColorTokens, type Coloration, HeadingLevel, type HeadingSizes, type IConfirmDialogController, type IDialogController, type INotificationsController, type Sizes, type SizesProp, Sizing, type Spacing, type SpacingDistribution, type SpacingType, TextSize, type TextSizes, type Texts, type Theme, ThemeColor, ThemeContext, type ThemeMapper, ThemeMapperStates, type ThemeMapperStyle, ThemeMapperStyles, type ThemeMapperValue, ThemeProperties, type Tokens, UiConfirmDialogContext, type UiConfirmDialogData, type UiConfirmDialogHolder, type UiConfirmDialogOptions, UiDialogsControllerContext, type UiNotification, type UiNotificationLink, type UiNotificationOptions, UiNotificationsContext, type UiReactElementProps, type UiReactPrivateElementProps, UiSpacing, type UiSpacingProps, UiViewport, getSpacingClass, getSpacingStyle, useConfirmDialogController, useDialogController, useNotificationsController, useViewport, type useViewportResponse };
