import * as React6 from 'react';
import React6__default, { useState, useMemo, useEffect, useCallback } from 'react';

// src/hooks/use-dialogs-controller.ts
var useDialogController = () => {
  const [openedDialogs, setOpenedDialogs] = React6__default.useState([]);
  const openDialog = React6__default.useCallback(
    (dialogId) => {
      const found = openedDialogs.filter((id) => id === dialogId);
      if (!found || found.length === 0) {
        const newOpenedDialogs = [...openedDialogs, dialogId];
        setOpenedDialogs(newOpenedDialogs);
      }
    },
    [openedDialogs, setOpenedDialogs]
  );
  const closeDialog = React6__default.useCallback(
    (dialogId) => {
      const newOpenedDialogs = openedDialogs.filter((id) => id !== dialogId);
      setOpenedDialogs(newOpenedDialogs);
    },
    [openedDialogs, setOpenedDialogs]
  );
  return {
    openDialog,
    closeDialog,
    openedDialogs
  };
};

// src/responsive/breakpoints-sizes.ts
var BreakpointsSizes = {
  s: {
    max: 579
  },
  m: {
    min: 580,
    max: 991
  },
  l: {
    min: 992,
    max: 1440
  },
  xl: {
    min: 1440
  }
};

// src/hooks/utils/get-window-deimensions.ts
var getWindowDimensions = () => {
  if (typeof window !== "undefined") {
    const { innerWidth: width, innerHeight: height } = window;
    return {
      width,
      height
    };
  }
  return {
    width: BreakpointsSizes.l.min,
    height: BreakpointsSizes.l.min
  };
};

// src/hooks/use-window-dimensions.ts
var useWindowDimensions = () => {
  const [windowDimensions, setWindowDimensions] = useState(getWindowDimensions());
  useEffect(() => {
    const handleResize = () => {
      setWindowDimensions(getWindowDimensions());
    };
    window.addEventListener("resize", handleResize);
    return () => window.removeEventListener("resize", handleResize);
  }, []);
  useEffect(() => {
    setWindowDimensions(getWindowDimensions());
  }, []);
  return windowDimensions;
};
var useViewport = () => {
  const { width } = useWindowDimensions();
  const [hydratred, setHydrated] = useState(false);
  const viewportResponse = useMemo(() => {
    const isSmall = width <= BreakpointsSizes.s.max;
    const isMedium = width >= BreakpointsSizes.m.min && width <= BreakpointsSizes.m.max;
    const isLarge = width >= BreakpointsSizes.l.min && width <= BreakpointsSizes.l.max;
    const isXLarge = width >= BreakpointsSizes.xl.min;
    return {
      isSmall,
      isMedium,
      isLarge,
      isXLarge
    };
  }, [width]);
  useEffect(() => {
    setHydrated(true);
  }, []);
  if (hydratred) {
    return viewportResponse;
  }
  return {
    isSmall: false,
    isMedium: false,
    isLarge: true,
    isXLarge: false
  };
};
var useNotificationsController = () => {
  const [notifications, setNotifications] = useState([]);
  const showNotification = useCallback(
    (notification) => {
      setNotifications([...notifications, notification]);
    },
    [notifications, setNotifications]
  );
  return {
    notifications,
    showNotification
  };
};
var useConfirmDialogController = () => {
  const [visible, setVisible] = useState(false);
  const [confirmDialogData, setConfirmDialogData] = useState(null);
  const hideConfirmDialog = useCallback(() => {
    setVisible(false);
  }, [setVisible]);
  const showConfirmDialog = useCallback(
    (data, onConfirm, onDeny, options) => {
      setVisible(true);
      setConfirmDialogData({
        data,
        confirm: onConfirm,
        deny: onDeny,
        options
      });
    },
    [confirmDialogData, setConfirmDialogData]
  );
  return {
    visible,
    confirmDialog: confirmDialogData,
    showConfirmDialog,
    hideConfirmDialog
  };
};
var noOpDialogControl = () => {
  console.error("No dialog controller implemented");
};
var UiDialogsControllerContext = React6__default.createContext({
  openDialog: noOpDialogControl,
  closeDialog: noOpDialogControl,
  openedDialogs: []
});
UiDialogsControllerContext.displayName = "UiDialogsControllerContext";

// src/types/breakpoints-enum.ts
var Breakpoints = /* @__PURE__ */ ((Breakpoints2) => {
  Breakpoints2[Breakpoints2["SMALL"] = 0] = "SMALL";
  Breakpoints2[Breakpoints2["MEDIUM"] = 1] = "MEDIUM";
  Breakpoints2[Breakpoints2["LARGE"] = 2] = "LARGE";
  Breakpoints2[Breakpoints2["XLARGE"] = 3] = "XLARGE";
  return Breakpoints2;
})(Breakpoints || {});

// src/types/enums/color-categories.ts
var ColorCategories = /* @__PURE__ */ ((ColorCategories2) => {
  ColorCategories2["fonts"] = "fonts";
  ColorCategories2["primary"] = "primary";
  ColorCategories2["secondary"] = "secondary";
  ColorCategories2["tertiary"] = "tertiary";
  ColorCategories2["positive"] = "positive";
  ColorCategories2["negative"] = "negative";
  ColorCategories2["error"] = "error";
  ColorCategories2["warning"] = "warning";
  return ColorCategories2;
})(ColorCategories || {});

// src/types/enums/color-tokens.ts
var ColorTokens = /* @__PURE__ */ ((ColorTokens2) => {
  ColorTokens2["token_10"] = "token_10";
  ColorTokens2["token_50"] = "token_50";
  ColorTokens2["token_100"] = "token_100";
  ColorTokens2["token_150"] = "token_150";
  ColorTokens2["token_200"] = "token_200";
  return ColorTokens2;
})(ColorTokens || {});

// src/types/enums/heading-levels.ts
var HeadingLevel = /* @__PURE__ */ ((HeadingLevel2) => {
  HeadingLevel2["level1"] = "level1";
  HeadingLevel2["level2"] = "level2";
  HeadingLevel2["level3"] = "level3";
  HeadingLevel2["level4"] = "level4";
  HeadingLevel2["level5"] = "level5";
  HeadingLevel2["level6"] = "level6";
  return HeadingLevel2;
})(HeadingLevel || {});

// src/types/enums/spacing.ts
var Sizing = /* @__PURE__ */ ((Sizing2) => {
  Sizing2["one"] = "one";
  Sizing2["two"] = "two";
  Sizing2["three"] = "three";
  Sizing2["four"] = "four";
  Sizing2["five"] = "five";
  Sizing2["six"] = "six";
  Sizing2["seven"] = "seven";
  return Sizing2;
})(Sizing || {});

// src/types/enums/theme-color.ts
var ThemeColor = /* @__PURE__ */ ((ThemeColor2) => {
  ThemeColor2["light"] = "light";
  ThemeColor2["dark"] = "dark";
  return ThemeColor2;
})(ThemeColor || {});

// src/types/enums/text-size.ts
var TextSize = /* @__PURE__ */ ((TextSize2) => {
  TextSize2["xsmall"] = "xsmall";
  TextSize2["small"] = "small";
  TextSize2["regular"] = "regular";
  TextSize2["large"] = "large";
  TextSize2["xlarge"] = "xlarge";
  return TextSize2;
})(TextSize || {});

// src/types/themes/theme.ts
var ThemeProperties = /* @__PURE__ */ ((ThemeProperties2) => {
  ThemeProperties2["name"] = "name";
  ThemeProperties2["texts"] = "texts";
  ThemeProperties2["sizes"] = "sizes";
  ThemeProperties2["light"] = "light";
  ThemeProperties2["dark"] = "dark";
  ThemeProperties2["spacing"] = "spacing";
  return ThemeProperties2;
})(ThemeProperties || {});

// src/types/theme-mapper.ts
var ThemeMapperStates = /* @__PURE__ */ ((ThemeMapperStates2) => {
  ThemeMapperStates2["normal"] = "normal";
  ThemeMapperStates2["hover"] = "hover";
  ThemeMapperStates2["active"] = "active";
  ThemeMapperStates2["selected"] = "selected";
  ThemeMapperStates2["disabled"] = "disabled";
  ThemeMapperStates2["visited"] = "visited";
  ThemeMapperStates2["focus"] = "focus";
  return ThemeMapperStates2;
})(ThemeMapperStates || {});
var ThemeMapperStyles = /* @__PURE__ */ ((ThemeMapperStyles2) => {
  ThemeMapperStyles2["color"] = "color";
  ThemeMapperStyles2["background"] = "background";
  ThemeMapperStyles2["borderColor"] = "border-color";
  ThemeMapperStyles2["fill"] = "fill";
  return ThemeMapperStyles2;
})(ThemeMapperStyles || {});

// src/providers/theme-context.ts
var ThemeContext = React6__default.createContext({
  selectedTheme: "light" /* light */
});
ThemeContext.displayName = "UiReactThemeContext";
var noOpNotification = () => {
  console.error("No show notification fn implemented");
};
var UiNotificationsContext = React6__default.createContext({
  showNotification: noOpNotification,
  notifications: []
});
UiNotificationsContext.displayName = "UiNotificationsContext";
var noOp = () => {
  console.error("No confirm dialog fn implemented");
};
var UiConfirmDialogContext = React6__default.createContext({
  showConfirmDialog: noOp,
  hideConfirmDialog: noOp,
  visible: false,
  confirmDialog: null
});
UiConfirmDialogContext.displayName = "UiConfirmDialogContext";
var UiViewport = ({ children, criteria, skipSSr }) => {
  const [hydrated, setHydrated] = React6.useState(false);
  const { isSmall, isMedium, isLarge, isXLarge } = useViewport();
  React6.useEffect(() => {
    setHydrated(true);
  }, []);
  if (skipSSr && !hydrated) {
    return null;
  }
  if (!hydrated) {
    const isCriteriaLarge = criteria === 2 /* LARGE */ || criteria === "m|l" || criteria === "l|xl" || criteria === "m|l|xl";
    const isCriteriaXLarge = criteria === 3 /* XLARGE */ || criteria === "l|xl" || criteria === "m|l|xl";
    if (isCriteriaLarge || isCriteriaXLarge) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
    return null;
  }
  if (isSmall) {
    const matchesCriteria = criteria === 0 /* SMALL */ || criteria === "s|m";
    if (matchesCriteria) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
  }
  if (isMedium) {
    const matchesCriteria = criteria === 1 /* MEDIUM */ || criteria === "s|m" || criteria === "m|l" || criteria === "m|l|xl";
    if (matchesCriteria) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
  }
  if (isLarge) {
    const matchesCriteria = criteria === 2 /* LARGE */ || criteria === "m|l" || criteria === "l|xl" || criteria === "m|l|xl";
    if (matchesCriteria) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
  }
  if (isXLarge) {
    const matchesCriteria = criteria === 3 /* XLARGE */ || criteria === "l|xl" || criteria === "m|l|xl";
    if (matchesCriteria) {
      return /* @__PURE__ */ React6.createElement(React6.Fragment, null, children);
    }
  }
  return null;
};
UiViewport.displayName = "UiViewport";

// src/spacing/get-spacing-class.ts
var getSpacingClass = (type, spacing) => {
  if (!spacing) {
    return "";
  }
  if (spacing.all) {
    return `${type}-${spacing.all}`;
  }
  if (spacing.block || spacing.inline) {
    let classes2 = "";
    if (spacing.block) {
      classes2 += `${type}-top-${spacing.block} ${type}-bottom-${spacing.block}`;
    }
    if (spacing.inline) {
      classes2 += ` ${type}-left-${spacing.inline} ${type}-right-${spacing.inline}`;
    }
    return classes2;
  }
  let classes = "";
  if (spacing.top) {
    classes += `${type}-top-${spacing.top}`;
  }
  if (spacing.bottom) {
    classes += ` ${type}-bottom-${spacing.bottom}`;
  }
  if (spacing.left) {
    classes += ` ${type}-left-${spacing.left}`;
  }
  if (spacing.right) {
    classes += ` ${type}-right-${spacing.right}`;
  }
  return classes;
};

// src/spacing/spacing.tsx
var UiSpacing = ({
  children,
  className = "",
  inline,
  margin,
  padding,
  testId
}) => /* @__PURE__ */ React6.createElement("div", { className: `${inline ? "inline" : ""} ${getSpacingClass("margin", margin)} ${getSpacingClass("padding", padding)} ${className}`, "data-testid": testId }, children);
var getSpacingStyle = (sizing) => {
  if (sizing.all) {
    return `var(--spacing-${sizing.all})`;
  }
  if (sizing.inline || sizing.block) {
    const blockValue = sizing.block ? `var(--spacing-${sizing.block})` : "0px";
    const inlineValue = sizing.inline ? `var(--spacing-${sizing.inline})` : "0px";
    return `${blockValue} ${inlineValue}`;
  }
  return `
    ${sizing.top ? `var(--spacing-${sizing.top})` : "0px"}
    ${sizing.right ? `var(--spacing-${sizing.right})` : "0px"}
    ${sizing.bottom ? `var(--spacing-${sizing.bottom})` : "0px"}
    ${sizing.left ? `var(--spacing-${sizing.left})` : "0px"}
  `;
};

export { Breakpoints, ColorCategories, ColorTokens, HeadingLevel, Sizing, TextSize, ThemeColor, ThemeContext, ThemeMapperStates, ThemeMapperStyles, ThemeProperties, UiConfirmDialogContext, UiDialogsControllerContext, UiNotificationsContext, UiSpacing, UiViewport, getSpacingClass, getSpacingStyle, useConfirmDialogController, useDialogController, useNotificationsController, useViewport };
